/***************************************************************************
                          chatdlg.ui.h  -  description
                             -------------------
    begin                : Wed Nov 22 23:10:15 EST 2006
    copyright         : (C) 2006 by Sergey Litvinov
    email                : linch@adsl.by
 ***************************************************************************/

/***************************************************************************
 *   This program is free software; you can redistribute it and/or modify  		   *
 *   it under the terms of the GNU General Public License as published by  		   *
 *   the Free Software Foundation; either version 2 of the License, or     		   *
 *  (at your option) any later version.                                   				   *
 ***************************************************************************/

void ChatDlg::init()
{
    timer = new QTimer(this);
    connect( timer, SIGNAL(timeout()), this, SLOT(timerEvent()) );
    
    smmenu = new QPopupMenu(this);
    for (int i = 0; i <= SM_SLEEP; i++) 
	smmenu->insertItem(QIconSet(QPixmap::fromMimeSource(smilespack[i].file)), QString(smilespack[i].smile).replace("&", "&&"), i);
    connect(smmenu, SIGNAL(activated(int)), this, SLOT(smileMenuAction(int)));
}

void ChatDlg::setup(const QString &un, const QString &id, const QString &st)
{
    unick = un;
    uid = id;
    setMode(st);
}

void ChatDlg::setMode(const QString &m)
{
    setCaption(unick + " (" + m + ")");
}

void ChatDlg::closeEvent(QCloseEvent *event)
{
    emit closeChat(uid);
    event->accept();
}

void ChatDlg::setStatus(const QString& text)
{
    statusLine->setText(text);
}

void ChatDlg::smileButtonClicked()
{
    smmenu->popup(QCursor::pos());
}

void ChatDlg::smileMenuAction(int i)
{
    messageedit->insert(smilespack[i].smile);
}

void ChatDlg::infoClicked()
{
    emit getInfo(unick);
}

void ChatDlg::historyClicked()
{
    emit openHistory(unick);
}

void ChatDlg::filesendClicked()
{
    emit sendFile(unick);
}

void ChatDlg::writeText(const QString& text)
{
    chatview->append(text);
    statusLine->setText(tr("Ready"));
    timer->stop();
}

void ChatDlg::setEstablished()
{
    statusLine->setText(tr("Connection established"));
    securPix->setPixmap(QPixmap::fromMimeSource("encrypted.png"));
}

void ChatDlg::setReady()
{
    statusLine->setText(tr("Ready"));
    securPix->setPixmap(QPixmap::fromMimeSource("encrypted.png"));
}

void ChatDlg::setClosed()
{
    statusLine->setText(tr("Connection closed"));
    securPix->setPixmap(QPixmap::fromMimeSource("decrypted.png"));  
}

void ChatDlg::sendButton_clicked()
{
    if (!messageedit->text().isEmpty())
    {
	emit sendMessage(uid, messageedit->text());
	messageedit->clear();
    }
}

void ChatDlg::onKeyPressed(int key)
{
    ticks = 3;    
    if (key == Key_Escape)
    {
	close();
	return;
    }
    if (!timer->isActive()) 
    {
	emit sendTypingMode(uid, 0);
	timer->start(1000, false);
    }
}

void ChatDlg::timerEvent()
{
    if(--ticks <=0 )
    {
	timer->stop();
	emit sendTypingMode(uid, 1);
    }
}
