/****************************************************************************
                          logs.cpp  -  description
                             -------------------
    begin                : Thu Sep 13 19:20:17 EST 2005
    copyright            : (C) 2004-2006 by Sergey Litvinov
    email                : linch@adsl.by
 ****************************************************************************/

/****************************************************************************
 *                                                                         							*
 *   This program is free software; you can redistribute it and/or modify  		   	*
 *   it under the terms of the GNU General Public License as published by  		   	*
 *   the Free Software Foundation; either version 2 of the License, or     		   	*
 *   (at your option) any later version.                                   				   	*
 *                                                                         					   		*
 ****************************************************************************/

#include <qdir.h>
#include <qfile.h>
#include <qfileinfo.h>
#include <qtextstream.h>
#include "logs.h"

Logs::Logs(const QString& p, int ms):path(p), maxsize(ms)
{
    setup();
}

Logs::~Logs()
{
    f.close();
}

bool Logs::setPath(const QString& p)
{
    f.close();
    path = p;
    setup();
    return true;
}

void Logs::setup()
{
    QFileInfo fi(path);
    QDir d(fi.dir(true));
	
    if (!d.exists()) 
	d.mkdir(d.absPath());

    f.setName(path);
    f.open(IO_ReadWrite | IO_Append);
}

bool Logs::setMaxSize(int s)
{
    maxsize = s;
    return true;
}

bool Logs::write(const QString &date, const QString &time, const QString &src, int type, const QString &user, const QString &txt)
{
    int addictsize, spos;
    QString tmp, tp;
    QString buffer;
    QString text = txt;
	
    if (maxsize == 0) return false;
    if ((int)f.size() > (maxsize * 1024))
    {
	f.reset();
	buffer = QString(f.readAll());
	f.close();	    
	addictsize = maxsize / 10;
	tmp = buffer.right((maxsize - addictsize) * 1024);
	spos = tmp.find("<LOG>");
	if (spos != -1) 
	{
	    buffer = tmp.mid(spos);
	    f.open(IO_WriteOnly);
	    f.writeBlock(buffer.data(), buffer.length());
	    f.close();
	}
	f.open(IO_ReadWrite | IO_Append);
    }
    
    switch(type)
    {
    case CHN_TYPE:
	tp = "<CHN>";
	break;
    case MSG_TYPE:
	tp = "<MSG>";
	break;
    case PRV_TYPE:
	tp = "<PRV>";
	break;
    default: break;
    }
//    text.replace("<", "&lt;");
//    text.replace(">", "&gt;");
    tmp = QString("<LOG><DATE>%1<DATE><TIME>%2<TIME>%3%4%5<USR>%6<USR>%7")
	  .arg(date)
	  .arg(time)
	  .arg(tp)
	  .arg(src)
	  .arg(tp)
	  .arg(user)
	  .arg(text);
	
    QTextStream stream(&f);
    stream.setEncoding(QTextStream::UnicodeUTF8);
    stream << tmp;
    f.flush();
    return true;
}
